import { useEffect, useState } from 'react';
import { Select } from 'antd'
import { getMachineryList, getMachineryDetail } from '@/services/machinery'

const Option = Select.Option;
export default (props) => {
  const { value, onChange, ...otherProps } = props;

  const [list, setList] = useState([])

  const searchData = (val) => {
    getMachineryList({ name: val, pageSize: 9999 }).then((res) => {
      setList(res.records || [])
    }).catch((err) => {
      console.log(err.message)
    });
  }

  const handleSearch = (text) => {
    if (text) {
      searchData(text)
    }
  }

  useEffect(() => {
    if (value) {
      getMachineryDetail(value).then((res) => {
        setList([res])
      }).catch((err) => {
        console.log(err.message)
      });
    }
  }, [value])

  return (
    <Select
      showSearch
      value={value}
      defaultActiveFirstOption={false}
      showArrow={false}
      filterOption={false}
      onSearch={handleSearch}
      onChange={onChange}
      notFoundContent={null}
      {...otherProps}
    >
      {
        list.map((item) => {
          return (
            <Option key={item.machineryId} value={item.machineryId}>{item.name}</Option>
          )
        })
      }
    </Select>
  )
}
