import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { Card, Button, Descriptions } from 'antd';
import { useEffect, useState } from 'react';
import { getJobDetail, getJobGISDetail } from '@/services/job'
import moment from 'moment';
import { history } from 'umi';
import getCoordinate from '@/utils/mapTogcj02'
import GISMap from '@/components/GISMap';

const goBack = () => {
  history.goBack();
};
const formatterTime = (val) => {
  return val ? moment(val).format('YYYY-MM-DD HH:mm') : '';
};
export default (props) => {
  const { location } = props;
  const { id } = location.query;
  const [workInfo, setWorkInfo] = useState()
  const [nlocationList, setNewLocationList] = useState()
  useEffect(() => {
    if (id) {
      getJobDetail(id).then((res) => {
        setWorkInfo(res)
        getJobGISDetail({ jobId: id }).then((gisRes => {
          let list, newlocation
          list = gisRes.map(item => {
            newlocation = getCoordinate(item.lng, item.lat);
            return [newlocation.longitude, newlocation.latitude]
          })
          setNewLocationList(list)
        })).catch(err => {
          console.log(err.message);
        })
      }).catch(err => {
        console.log(err.message);
      })
    }
  }, [id])
  return (
    <PageHeaderWrapper extra={[<Button key={id} type="default" onClick={() => goBack()}>
      返回
    </Button>]}>
      <Card title='作业详情'>
        <Descriptions labelStyle={{ justifyContent: 'flex-end', minWidth: '5em' }} >
          <Descriptions.Item label="订单号">{workInfo?.orderNo}</Descriptions.Item>
          <Descriptions.Item label="合作社">{workInfo?.orgName}</Descriptions.Item>
          <Descriptions.Item label="农机">{workInfo?.machineryName}</Descriptions.Item>
          <Descriptions.Item label="农机手">{workInfo?.workerName}</Descriptions.Item>
          <Descriptions.Item label="作业面积">{workInfo?.area}亩</Descriptions.Item>
          <Descriptions.Item label="作业时间">{formatterTime(workInfo?.startDate)}~{formatterTime(workInfo?.endDate)}</Descriptions.Item>
          <Descriptions.Item label="作业地址">{workInfo?.address}</Descriptions.Item>
        </Descriptions>
      </Card>
      <Card style={{ minHeight: '700px', marginTop: '32px' }}>
        <GISMap lineArr={nlocationList} />
      </Card>
    </PageHeaderWrapper>
  );
};
