import React, { useCallback, useEffect, useRef } from 'react';
import { Swiper, SwiperSlide } from 'swiper/react';
import { Autoplay } from 'swiper';
import 'swiper/css';
import classNames from 'classnames';
import Item from './Item';
import Styles from './style.less';

export default (props) => {
  const { title, color, children } = props;
  const swiperRef = useRef();
  const classList = classNames(Styles['list-title'], {
    [Styles['yellow-title']]: color !== 'green',
    [Styles['green-title']]: color === 'green',
  });
  const initAutoPlay = useCallback(
    (swiper) => {
      if (!children?.length || children?.length <= 3) {
        swiper.autoplay.stop();
      } else {
        swiper.autoplay.start();
      }
    },
    [children?.length],
  );

  useEffect(() => {
    if (swiperRef.current) {
      initAutoPlay(swiperRef.current);
    }
  }, [children?.length, initAutoPlay]);

  const enable = children?.length && children?.length > 3;

  return (
    <div className={Styles['screen-list']}>
      <div className={classList}>
        <div>{title}</div>
      </div>
      <Swiper
        height={48}
        onSwiper={(swiper) => {
          swiperRef.current = swiper;
          initAutoPlay(swiper);
        }}
        className={Styles['list-body']}
        //因为loop只能在组件初始化时改变所以加一个不让它创建初始化的属性就可以了
        init={false}
        autoplay={{
          delay: 2500,
          disableOnInteraction: false,
        }}
        loop={enable}
        loopAdditionalSlides={2}
        modules={[Autoplay]}
        direction="vertical"
      >
        {React.Children.map(children, (child) => (
          <SwiperSlide>
            <Item color={color}>{child}</Item>
          </SwiperSlide>
        ))}
      </Swiper>
    </div>
  );
};
