import React, { useState, useEffect } from 'react';
import { Card, Form, Button } from 'antd';
import ProCard from '@ant-design/pro-card';
import { getOrderDetail } from '@/services/order';
import { history } from 'umi';

const FormItem = Form.Item;
const formItemLayout = { labelCol: { span: 6 }, wrapperCol: { span: 14 } };
const goBack = () => {
  history.goBack();
};
export default (props) => {
  const { location } = props;
  const { id } = location.query;
  const [dispatch, setDispatch] = useState();

  useEffect(() => {
    getOrderDetail(id)
      .then((res) => {
        setDispatch(res);
      })
      .catch((err) => {
        console.log(err.message);
      });
  }, [id]);
  return (
    <Card>
      <ProCard tabs={{ type: 'card' }}>
        <ProCard.TabPane key={1} tab="订单详情">
          <Form {...formItemLayout}>
            <FormItem label="订单号">{dispatch?.orderNo}</FormItem>
            <FormItem label="农户姓名">{dispatch?.personName}</FormItem>
            <FormItem label="联系电话">{dispatch?.phone}</FormItem>
            <FormItem label="预约地址">{dispatch?.address}</FormItem>
            <FormItem label="预约时间">{dispatch?.appointmentDate}</FormItem>
            <FormItem label="合作社名">{dispatch?.orgName}</FormItem>
            <FormItem label="农机类型">{dispatch?.typeName}</FormItem>
            <FormItem label="农机">{dispatch?.machineryName}</FormItem>
            <FormItem label="农机手">{dispatch?.workName}</FormItem>
            <FormItem label=" " colon={false}>
              <Button type="default" onClick={() => goBack()}>
                返回
              </Button>
            </FormItem>
          </Form>
        </ProCard.TabPane>
      </ProCard>
    </Card>
  );
};
